This package performs estimation and inference for the parameters of a
bivariate normal regression model. Estimation is performed using fit.bnr.
Inference on regression parameters for the target outcome is performed using
test.bnr.
Zachary R. McCaw
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.